# Input datasets

```{eval-rst}
.. automodule:: deepali.data.dataset
    :noindex:
```

## Generic datasets

```{eval-rst}
.. autoapisummary::

    deepali.data.dataset.MetaDataset
    deepali.data.dataset.GroupDataset
    deepali.data.dataset.JoinDataset

```

## Image datasets

```{eval-rst}
.. autoapisummary::

    deepali.data.dataset.ImageDataset
    deepali.data.dataset.ImageDatasetConfig

```
